# Quality Assessment Tools at museum-digital

The classes of this library provide tools to access the quality of museum object
records and provide tips for improving it.

## Tools

### PuQI

PuQI (class `MDPuqi`) generates a score determining the quality of object metadata
based on e.g. counting linked entries, checking the length of an object's description,
and more.
Along with the score, a list of tips is generated to describe how to improve the
metadata quality in a human-readable form.

### Plausi

Plausi analyzes an object's linked events (e.g. production, use, etc.) and identifies
logical inconsistencies. A warning may e.g. be returned, if:

- the stated artist of an artwork has died before the stated time of creation of the object.
- events contradict each other, such as a usage of the object supposedly taking place before
  the object was created.

###  Plausibility Check for Image Licenses

This check analyses an object's event and image metadata to check for potential licensing issues.
E.g., an object that has been created by people who have not lived since the 1800s, many
jurisdictions automatically retire copyright on the object and purely documentary photographies
thereof. Hence, a warning will be returned if such an object's representations are not marked
as in the public domain.

Similarly, almost all jurisdictions protect the works of living authors / artists. If the object's
creator can thus be identified as still alive or only recently deceased, while the object's
representations are licensed under a permissive license or marked as in the public domain,
a warning will be returned. Obviously, this means that warnings are returned even where the
actual artist licensed their works under a Creative Commons license. The plausibility check for image
licenses should hence *NEVER be used for fully automated editing*.

Optionally, a list of creators represented by copyright collectives may be provided. If
such a creator can be identified among the object's creators, the returned warning will
contain an additional notice about the creator being represented by one along with tips
on how to get in contact with the copyright collective.

### Additional Tools

#### Minimaldatensatz: Check for Availability of Fields Required and Recommended by the AG Minimaldatensatz

See <http://minimaldatensatz.de>

## Publications

### PuQI

- Rohde-Enslin, S. (2014). "PuQi - Eine Versuchung." Paper presented at the Autumn Seminar of the Working Group Documentation of the German Museum Association, 2014 (Herbsttagung der FG Dokumentation des Deutschen Museumsbunds). <https://files.museum-digital.org/de/Praesentationen/2014-10-06_PuQI-Eine-Versuchung_SRE.pdf>
- Rohde-Enslin, S. (2015). PuQI – A Smart Way to Create Better Data. Uncommon Culture, 6(2), 122-129. <https://uncommonculture.org/ojs/index.php/UC/article/view/6218>
- Rohde-Enslin, S. (2021). "PuQi – Verführung zu Qualität." museum-digital:blog, <https://blog.museum-digital.org/de/2021/01/22/ein-publikations-qualitaets-index-fuer-museumsobjektinformationen/>

### Plausi

- Rohde-Enslin, S. (2017). "Plausi - PuQI hat einen Freund bekommen." Paper presented at the Autumn Seminar of the Working Group Documentation of the German Museum Association, 2017 (Herbsttagung der FG Dokumentation des Deutschen Museumsbunds). <https://files.museum-digital.org/de/Praesentationen/2017-11_Plausi-FG-Doku-Berlin_SRE.pdf>

